@@ -31,7 +31,7 @@ class XmlElement:
         Keyword arguments:
         subelement -- XmlElement
         """
-        self.subelements.append(subelement)
+        self.subelements = [ *self.subelements, subelement]
 
 
     def extend(self, subelements: List[XmlElement]) -> None:
@@ -39,7 +39,7 @@ class XmlElement:
         Keyword arguments:
         subelement -- Set of XmlElements
         """
-        self.subelements.extend(subelements)
+        self.subelements = [ *self.subelements, *subelements ]
         
 
     def to_etree_element(self) -> Element:
